@@ -1,27 +1,26 @@
 ''' Read font file and write glyphs to SVG '''
 
 from __future__ import annotations
-from typing import Literal, Sequence, Union, Optional, Dict
+from typing import Literal, Union, Optional, Dict
 import sys
 import os
+import math
 from pathlib import Path
 from collections import namedtuple
 import importlib.resources as pkg_resources
 import xml.etree.ElementTree as ET
+import warnings
 
+from .config import config
 from .fontread import FontReader
 from . import gpos
 from .cmap import Cmap12, Cmap4
-from .glyph import read_glyph, dflt_fontsize, fmt, SimpleGlyph, CompoundGlyph
-from .fonttypes import AdvanceWidth, Layout, Header, Table, FontInfo, FontNames
+from .glyph import read_glyph, fmt, SimpleGlyph, CompoundGlyph
+from .fonttypes import AdvanceWidth, Layout, Header, Table, FontInfo, FontNames, Symbols
 
 
-DEBUG = False
-
 fontindex = None
 
-Symbols = namedtuple('Symbols', ['word', 'symbols', 'width', 'ymin', 'ymax'])
-
 
 class Font:
     ''' Class to read/parse a OpenType/TTF and write glyphs to SVG
@@ -30,14 +29,15 @@ class Font:
             name: File name of the font
             style: Font style such as "bold" or "italic", used when searching
                 system paths for a font file
-            svg2: Use SVG Version 2.0. Disable for better compatibility.
     '''
-    def __init__(self, name: Union[str, Path]=None, style: str='regular', svg2: bool=True):
+    def __init__(self, name: Union[str, Path]=None, style: str='regular'):
         self.fname = None
         if name and Path(name).exists():
             self.fname = Path(name)
         elif name:
             self.fname = findfont(name, style)
+            if self.fname is None:
+                warnings.warn(f'Font {name} not found.')
 
         if self.fname is None:
             with pkg_resources.path('ziafont.fonts', 'DejaVuSans.ttf') as p:
@@ -46,7 +46,6 @@ class Font:
         with open(self.fname, 'rb') as f:
             self.fontfile = FontReader(f.read())
         self.info = self._loadfont()  # Load in all the font metadata
-        self.svg2 = svg2
         self._glyphs: Dict[int, Union[SimpleGlyph, CompoundGlyph]] = {}
         self._glyphids: Dict[str, int] = {}
 
@@ -324,55 +323,69 @@ class Font:
         txt = Text(s, self)
         return txt.getsize()
 
-    def str2svg(self, s: str, fontsize: float=None, linespacing: float=1,
-                halign: Literal['left', 'center', 'right']='left',
-                valign: Literal['base', 'center', 'top']='base',
-                canvas: ET.Element=None,
-                xy: Sequence[float]=(0, 0),
-                kern=True):
-        ''' Convert a string to SVG
+    def text(self, s: str,
+             size: float=None,
+             linespacing: float=1,
+             halign: Literal['left', 'center', 'right']='left',
+             valign: Literal['base', 'center', 'top']='base',
+             color: str=None,
+             rotation: float=0,
+             rotation_mode: str='anchor',
+             kern=True):
+        ''' Create a Text object using this font
 
             Args:
                 s: String to convert.
-                fontsize: Font size in points
+                size: Font size in points
                 linespacing: Space between lines
                 halign: Horizontal Alignment
                 valign: Vertical Alignment
-                canvas: SVG XML element to draw on
-                xy: Position to draw on canvas
+                color: Color for string
+                rotation: Rotation angle in degrees
+                rotation_mode: Either 'default' or 'anchor', to
+                    mimic Matplotlib behavoir. See:
+                    https://matplotlib.org/stable/gallery/text_labels_and_annotations/demo_text_rotation_mode.html
                 kern: Use font kerning adjustment
         '''
-        txt = Text(s, self, fontsize, linespacing, halign, valign, kern=kern, svg2=self.svg2)
-        if canvas is not None:
-            txt.drawon(canvas, xy[0], xy[1])
+        txt = Text(s, self, size=size, linespacing=linespacing, halign=halign, valign=valign,
+                   color=color, kern=kern, rotation=rotation,
+                   rotation_mode=rotation_mode)
         return txt
 
 
 class Text:
-    ''' Convert XML Element to SVG text with Jupyter representer.
+    ''' Draw text as SVG paths
 
         Args:
             s: String to draw
             font: Font name or ziafont.Font to use
             size: Font size in points
             linespacing: Spacing between lines
+            color: Color for string
             halign: Horizontal Alignment
             valign: Vertical Alignment
+            rotation: Rotation angle in degrees
+            rotation_mode: Either 'default' or 'anchor', to
+                mimic Matplotlib behavoir. See:
+                https://matplotlib.org/stable/gallery/text_labels_and_annotations/demo_text_rotation_mode.html
             kern: Use kerning adjustment
-            svg2: Use SVG Version 2.0. Disable for better compatibility.
     '''
     def __init__(self, s: str,  font: Union[str, Font]=None,
                  size: float=None, linespacing: float=1,
                  halign: Literal['left', 'center', 'right']='left',
                  valign: Literal['base', 'center', 'top']='base',
-                 kern: bool=True,
-                 svg2: bool=True):
+                 color: str=None,
+                 rotation: float=0,
+                 rotation_mode: str='anchor',
+                 kern: bool=True):
         self.str = s
         self.halign = halign
         self.valign = valign
-        self.size = size if size else dflt_fontsize()
+        self.color = color
+        self.rotation = rotation
+        self.rotation_mode = rotation_mode
+        self.size = size if size else config.fontsize
         self.linespacing = linespacing
-        self.svg2 = svg2
         self.kern = kern
         if font is None or isinstance(font, str):
             self.font = Font(font)
@@ -384,7 +397,7 @@ class Text:
         ''' Get SVG XML element '''
         svg = ET.Element('svg')
         svg.attrib['xmlns'] = 'http://www.w3.org/2000/svg'
-        if self.svg2:
+        if config.svg2:
             svg.attrib['xmlns:xlink'] = 'http://www.w3.org/1999/xlink'
         ret, (xmin, xmax, ymin, ymax) = self._drawon(svg)
         w = xmax-xmin
@@ -411,7 +424,6 @@ class Text:
         ''' Draw text on the SVG '''
         word, symbols, width, ymin, ymax = self._symbols
         height = ymax-ymin
-        xyorig = x, y
         # Adjust vertical alignment
         yofst = {'base': 0,
                  'bottom': -ymax,
@@ -422,32 +434,81 @@ class Text:
         xy = x + xofst, y + yofst
 
         # Get existing symbol/glyphs, add ones not there yet
-        if self.svg2:
+        if config.svg2:
             existingsymbols = svg.findall('symbol')
             symids = [sym.attrib.get('id') for sym in existingsymbols]
             for sym in symbols:
                 if sym not in symids:
                     svg.append(sym)
+
+        xform = ''
         if xy != (0, 0):
-            word.attrib['transform'] = f'translate({fmt(xy[0])} {fmt(xy[1])})'
+            xform = f'translate({fmt(xy[0])} {fmt(xy[1])})'
 
         svg.append(word)
 
-        if DEBUG:  # Test viewbox
-            rect = ET.SubElement(svg, 'rect')
-            rect.attrib['x'] = fmt(xy[0])
-            rect.attrib['y'] = fmt(xy[1]+ymin)
+        if config.debug:  # Test viewbox
+            rect = ET.SubElement(word, 'rect')
+            rect.attrib['x'] = '0'
+            rect.attrib['y'] = fmt(ymin)
             rect.attrib['width'] = fmt(width)
             rect.attrib['height'] = fmt(height)
             rect.attrib['fill'] = 'none'
             rect.attrib['stroke'] = 'red'
-            circ = ET.SubElement(svg, 'circle')
-            circ.attrib['cx'] = f'{fmt(xyorig[0])}'
-            circ.attrib['cy'] = f'{fmt(xyorig[1])}'
+            circ = ET.SubElement(word, 'circle')
+            circ.attrib['cx'] = fmt(-xofst)
+            circ.attrib['cy'] = fmt(-yofst)
             circ.attrib['r'] = '3'
             circ.attrib['fill'] = 'red'
             circ.attrib['stroke'] = 'red'
-        return svg, (xy[0], xy[0]+width, ymin, ymax)
+        bbox = (xy[0], xy[0]+width, xy[1]+ymin, xy[1]+ymax)
+
+        if self.rotation:
+            centerx = xy[0]  # Center of rotation
+            centery = xy[1]
+            costh = math.cos(math.radians(self.rotation))
+            sinth = math.sin(math.radians(self.rotation))
+            p1 = (xofst, ymin+yofst)  # Corners relative to rotation point
+            p2 = (xofst+width, ymin+yofst)
+            p3 = (xofst+width, ymax+yofst)
+            p4 = (xofst, ymax+yofst)
+            x1 = centerx + (p1[0]*costh + p1[1]*sinth) - xofst
+            x2 = centerx + (p2[0]*costh + p2[1]*sinth) - xofst
+            x3 = centerx + (p3[0]*costh + p3[1]*sinth) - xofst
+            x4 = centerx + (p4[0]*costh + p4[1]*sinth) - xofst
+            y1 = centery - (p1[0]*sinth - p1[1]*costh) - yofst
+            y2 = centery - (p2[0]*sinth - p2[1]*costh) - yofst
+            y3 = centery - (p3[0]*sinth - p3[1]*costh) - yofst
+            y4 = centery - (p4[0]*sinth - p4[1]*costh) - yofst
+            bbox = (min(x1, x2, x3, x4), max(x1, x2, x3, x4),
+                    min(y1, y2, y3, y4), max(y1, y2, y3, y4))
+
+            if self.rotation_mode == 'default':
+                dx = {'left': x - bbox[0],
+                      'right': x - bbox[1],
+                      'center': x - (bbox[1]+bbox[0])/2}.get(self.halign, 0)
+                dy = {'top': y - bbox[2],
+                      'bottom': y - bbox[3],
+                      'base': -sinth*dx,
+                      'center': y - (bbox[3]+bbox[2])/2}.get(self.valign, 0)
+                xform = f'translate({xy[0]+dx} {xy[1]+dy})'
+                bbox = (bbox[0]+dx, bbox[1]+dx,
+                        bbox[2]+dy, bbox[3]+dy)
+            xform += f' rotate({-self.rotation} {-xofst} {-yofst})'
+
+        if config.debug:
+            rect = ET.SubElement(svg, 'rect')
+            rect.attrib['x'] = fmt(bbox[0])
+            rect.attrib['y'] = fmt(bbox[2])
+            rect.attrib['width'] = fmt(bbox[1]-bbox[0])
+            rect.attrib['height'] = fmt(bbox[3]-bbox[2])
+            rect.attrib['fill'] = 'none'
+            rect.attrib['stroke'] = 'blue'
+
+        word.attrib['transform'] = xform
+        if self.color:
+            word.attrib['fill'] = self.color
+        return svg, bbox
 
     def _buildstring(self) -> Symbols:
         ''' Create symbols and svg word in a <g> group tag, for placing in an svg '''
@@ -495,7 +556,7 @@ class Text:
         ymin = yvals[0] - self.font.info.layout.ascent*scale
         ymax = yvals[-1] - self.font.info.layout.descent*scale
 
-        if not self.svg2:
+        if not config.svg2:
             symbols = []
         return Symbols(word, symbols, totwidth, ymin, ymax)
 
@@ -544,6 +605,9 @@ def _build_fontlist():
 
 def findfont(name, style='Regular'):
     ''' Find a font file by name '''
+    if name is None:
+        return None
+
     if Path(name).exists():
         return Path(name)
 
